@@ -1,21 +1,32 @@
 """Vector utilities"""
 import logging
+from pathlib import Path
+from typing import Any
 
 import geopandas as gpd
+import numpy as np
+import fiona
 import rasterio
+from geopandas import GeoDataFrame
+from rasterio import Affine
 from rasterio.features import shapes
+from rasterio.windows import Window
 from shapely.geometry import MultiPolygon, Polygon
 
 UTILS_VECTOR_LOGGER = logging.getLogger(__name__)
 
-def vectorize_array(array_to_vectorize, transform=None):
+
+def vectorize_array(
+        array_to_vectorize: np.ndarray,
+        transform: Affine = None) -> GeoDataFrame:
     """Vectorize a tif file and return geodataframe.
 
     Args
-        array_to_vectorize (path):a rray to vectorize_and_classify
+        array_to_vectorize (array): Array to vectorize_and_classify
+        transform (Affine): Affine transformation
 
     Returns:
-        geodataframe with polygons
+        GeoDataFrame: geodataframe with polygons
 
     """
     polygonized = shapes(array_to_vectorize,
@@ -28,7 +39,9 @@ def vectorize_array(array_to_vectorize, transform=None):
     return gpd.GeoDataFrame.from_dict(new_poly_dict)
 
 
-def get_subset_of_polygons(window, transform, polygons, col_name='max'):
+def get_subset_of_polygons(
+        window: Window, transform: dict, polygons: GeoDataFrame,
+        col_name: str = 'max') -> list:
     """Get a subset of a geodataframe from a rasterio window
 
     Uses a rasterio window to make an intersection on the whole polygon
@@ -43,7 +56,6 @@ def get_subset_of_polygons(window, transform, polygons, col_name='max'):
     Returns:
         list of [geometry, value] pairs that can be consumed by GeoPandas
 
-
     """
     left, bottom, right, top = rasterio.windows.bounds(window,
                                                        transform)
@@ -65,17 +77,31 @@ def get_subset_of_polygons(window, transform, polygons, col_name='max'):
                     list(subset_polygons[col_name].values)))
 
 
-def gdf_polygon_to_multipolygon(gdf):
+def gdf_polygon_to_multipolygon(gdf: GeoDataFrame) -> GeoDataFrame:
     """Converts all geometries to multipolyon, so there are no issues when
     saving these to a file and adds a crs (epsg:4326) to the gdf
 
-        Args:
-            gdf (GeoDataFrame): Containing polygons
+    Args:
+        gdf (GeoDataFrame): Containing polygons
 
-        Returns:
-            gdf (GeoDataFrame): GDF with all polygons converted to multipolygons
+    Returns:
+        gdf (GeoDataFrame): GDF with all polygons converted to multipolygons
 
     """
     geometry = [MultiPolygon([feature]) if isinstance(feature, Polygon)
                 else feature for feature in gdf["geometry"]]
     return geometry
+
+
+def get_rois_extent(rois: Path) -> Any:
+    """
+
+    Args:
+        rois (Path): path to a rois file
+
+    Returns:
+        bounds of rois (list): ulx, uly, llx, lly coordinates
+
+    """
+    with fiona.open(rois, "r") as shapefile:
+        return shapefile.bounds
