@@ -1,15 +1,16 @@
 """ Unittests for config file"""
+from classifier.utils.config import (
+    AccuracyConfiguration, AppConfiguration, Configuration,
+    OptimizeSupervisedConfiguration, RandomForestConfiguration,
+    SupervisedConfiguration, UnsupervisedConfiguration, json_to_config)
+from classifier.utils.config import DtwConfiguration, json_to_config
 import copy
 import json
 import os
 import unittest
 
-from classifier.settings import PARAMETERS, WORKSPACE
-from classifier.utils.config import (AccuracyConfiguration, AppConfiguration,
-                                     Configuration,
-                                     OptimizeSupervisedConfiguration,
-                                     SupervisedConfiguration,
-                                     UnsupervisedConfiguration, json_to_config)
+from classifier.utils.config import PARAMETERS
+from classifier.settings import WORKSPACE
 
 
 class ConfigTestCase(unittest.TestCase):
@@ -33,11 +34,6 @@ class ConfigTestCase(unittest.TestCase):
         all_probabilities = False
         optimize = False  # Optimize the model parameters
         optimize_number = 10  # Number of iterations for optimization
-        max_features = ["auto", "sqrt", "log2"]
-        max_leaf_nodes = [3, 5, 7]
-        max_depth = [None, 1, 3, 10, 20000]
-        n_estimators = [10, 50, 100]
-        boxplots = False  # Plot Boxplots for samples
         remove_outliers = True  # Remove outliers from the training data
         nclasses = 2  # Number of classes for unsupervised
         trainfraction = 1.0  # Fraction of raster ed for training
@@ -59,17 +55,64 @@ class ConfigTestCase(unittest.TestCase):
             SupervisedConfiguration(
                 probability=probability,
                 all_probabilities=all_probabilities,
-                boxplots=boxplots,
                 remove_outliers=remove_outliers,
                 optimization=OptimizeSupervisedConfiguration(
                     optimize=optimize,
-                    optimize_number=optimize_number,
-                    max_features=max_features,
-                    max_leaf_nodes=max_leaf_nodes,
-                    max_depth=max_depth,
-                    n_estimators=n_estimators)),
+                    optimize_number=optimize_number),
+            ),
             UnsupervisedConfiguration(nclasses, trainfraction),
-            AccuracyConfiguration(perform_assesment, testfraction))
+            AccuracyConfiguration(perform_assesment, testfraction),
+            DtwConfiguration(
+                patterns=None,
+                patterns_save=False,
+                number_of_patterns_per_class=1,
+                n_neighbors=1,
+                window=None,
+                max_dist=None,
+                use_pruning=False,
+                penalty=None,
+                optimization_parameters={
+                    "n_neighbors": [1],
+                    "number_of_patterns_per_class": [1],
+                    "window": [None],
+                    "penalty": [None]
+                }
+            ),
+            RandomForestConfiguration(
+                n_estimators=100,
+                criterion="gini",
+                max_depth=None,
+                min_samples_split=2,
+                min_samples_leaf=1,
+                min_weight_fraction_leaf=0.0,
+                max_features="auto",
+                max_leaf_nodes=None,
+                min_impurity_decrease=0.0,
+                bootstrap=True,
+                oob_score=False,
+                random_state=None,
+                verbose=0,
+                class_weight=None,
+                ccp_alpha=0.0,
+                max_samples=None,
+                optimization_parameters={
+                    "max_features": ['auto', 'sqrt', 'log2'],
+                    "max_leaf_nodes": [3, 5, 7],
+                    "max_depth": [None, 1, 3, 10, 20000],
+                    "n_estimators": [10, 50, 100],
+                    "min_samples_split": [2],
+                    "min_samples_leaf": [1],
+                    "min_weight_fraction_leaf": [0.0],
+                    "min_impurity_decrease": [0.0],
+                    "oob_score": [False],
+                    "class_weight": [None],
+                    "ccp_alpha": [0.0],
+                    "max_samples": [None]
+                }
+            ),
+            name='',
+            tmp_dir=None
+        )
 
     def test_read_config_file_outputasexpected(self):
         """Config file is correctly read in"""
