@@ -1,7 +1,4 @@
 "Unsupervised classification test for classifier"
-from pathlib import Path
-
-import numpy as np
 import pytest
 import rasterio
 from classifier.cli import classification
@@ -10,7 +7,7 @@ from classifier.utils.general import save_config_as_json
 
 
 @pytest.mark.parametrize('test_arg',
-                         [[False, False]])
+                         [[False, False, False]])
 def test_unsupervised_kmeans(runner):
     """
     Test for running an unsupervised kmeans classification
@@ -20,15 +17,14 @@ def test_unsupervised_kmeans(runner):
     runner.invoke(classification, [
         "--name", 'test_result', '--overwrite', True,
         "integration_test_rasters"])
-    directory = Path(WORKSPACE) / 'test_result' / 'classification.tif'
+    directory = WORKSPACE / 'test_result' / 'classification.tif'
     with rasterio.open(directory, 'r') as dst:
         result = dst.read(1)
-        assert np.all(result[:, 0:4] == result[0, 0])
-        assert np.all(result[:, 5:10] == result[0, 5])
+        assert (result[:, 0:5] != result[:, 5:10]).all()
 
 
 @pytest.mark.parametrize('test_arg',
-                         [[False, False]])
+                         [[False, False, False]])
 def test_unsupervised_kmeans_minibatch(runner):
     """
     Test for running an unsupervised kmeans-minibatch classification
@@ -38,8 +34,7 @@ def test_unsupervised_kmeans_minibatch(runner):
     runner.invoke(classification, [
         "--name", 'test_result', '--overwrite', True,
         "integration_test_rasters"])
-    directory = Path(WORKSPACE) / 'test_result' / 'classification.tif'
+    directory = WORKSPACE / 'test_result' / 'classification.tif'
     with rasterio.open(directory, 'r') as dst:
         result = dst.read(1)
-        assert np.all(result[:, 0:4] == result[0, 0])
-        assert np.all(result[:, 5:10] == result[0, 5])
+        assert (result[:, 0:5] != result[:, 5:10]).all()
